﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using System.Collections.ObjectModel;
using Infragistics;
using Infragistics.Controls.Grids;
using Infragistics.Controls.Grids.Primitives;
using System.Windows.Data;

namespace XamWebGridCustomGrouping
{
    public partial class MainPage : UserControl
    {
        public MainPage()
        {
            InitializeComponent();

            //setup the grid to use the sales dataset
            this.igGrid.ItemsSource = Product.LoadData();
        }

        private void igGrid_Loaded(object sender, RoutedEventArgs e)
        {
            //expand the first group - the critical stock items list
          //  this.igGrid.Rows[0].IsExpanded = true;
        }

        private void Button_Click(object sender, RoutedEventArgs e)
        {
            Button btn = sender as Button;
            if (btn != null)
            {
                Product prod = ((Infragistics.Controls.Grids.UnboundColumnDataContext)(btn.DataContext)).Value as Product;
                if (prod != null)
                {
                    //order minimum quantity of item, then update grid
                    prod.UnitsInStock += prod.ReorderLevel + 10;
                    //force an update of the grid to reflect the data change
                    igGrid.InvalidateData();
                    //expand the first group
                    this.igGrid.Rows[0].IsExpanded = true;
                }
            }
        }

        private void igGrid_GroupByCollectionChanged(object sender, GroupByCollectionChangedEventArgs e)
        {
            var childgrid= sender as XamGrid;
            if (e.NewGroupedColumns.Count > 0)
            {
                childgrid.GroupBySettings.GroupByColumns.Grid.PagerSettings.AllowPaging = PagingLocation.None;
                //((XamGrid)childgrid.GroupBySettings.GroupByColumns.Grid.Parent).PagerSettings.AllowPaging = PagingLocation.Bottom;
            }
           
            childgrid.PagerSettings.AllowPaging = PagingLocation.Bottom;
        }
    }
    public class XamGridEx : XamGrid
    {

        #region Active Child Item
        public object CurrentActiveItem
        {
            get { return (object)GetValue(CurrentActiveItemProperty); }
            set { SetValue(CurrentActiveItemProperty, value); OnPropertyChanged("CurrentActiveItem"); }
        }

        // Using a DependencyProperty as the backing store for CurrentActiveItem.  This enables animation, styling, binding, etc...
        public static readonly DependencyProperty CurrentActiveItemProperty =
            DependencyProperty.Register("CurrentActiveItem",
            typeof(object),
            typeof(XamGridEx),
            new PropertyMetadata(null,
                (ss, ee) =>
                {
                    if (ss is XamGridEx)
                    {
                        Row row = (ss as XamGridEx).GetChildRowFromDataItem((ss as XamGridEx).Rows, ee.NewValue, null);
                        (ss as XamGridEx).ScrollCellIntoView(row.Cells[0]);
                        row.IsSelected = true;

                    }
                }));
        #endregion

        #region Helper Methods
        internal Row GetChildRowFromDataItem(RowCollection rows, object data, Row result)
        {
            if (result != null)
                return result;
            foreach (Row row in rows)
            {
                if (row.Data.Equals(data))
                {
                    result = row;
                }
                else
                {
                    foreach (ChildBand band in row.ChildBands)
                    {
                        result = GetChildRowFromDataItem(band.Rows, data, result);
                    }
                }
            }

            return result;
        }
        #endregion

        #region Base Overrides
        protected override void OnActiveCellChanged()
        {
            base.OnActiveCellChanged();
            CurrentActiveItem = this.ActiveCell.Row.Data;
        }
        #endregion
    }

    public class PagerTemplateChanger
    {
        #region ParentPagerTemplate

        public static ControlTemplate GetParentPagerTemplate(DependencyObject obj)
        {
            return (ControlTemplate)obj.GetValue(ParentPagerTemplateProperty);
        }

        public static void SetParentPagerTemplate(DependencyObject obj, ControlTemplate value)
        {
            obj.SetValue(ParentPagerTemplateProperty, value);
        }

        // Using a DependencyProperty as the backing store for ParentPagerTemplate.  This enables animation, styling, binding, etc...
        public static readonly DependencyProperty ParentPagerTemplateProperty =
            DependencyProperty.RegisterAttached("ParentPagerTemplate", typeof(ControlTemplate), typeof(PagerTemplateChanger), new PropertyMetadata(null));

        #endregion

        #region ChildPagerTemplate

        public static ControlTemplate GetChildPagerTemplate(DependencyObject obj)
        {
            return (ControlTemplate)obj.GetValue(ChildPagerTemplateProperty);
        }

        public static void SetChildPagerTemplate(DependencyObject obj, ControlTemplate value)
        {
            obj.SetValue(ChildPagerTemplateProperty, value);
        }

        // Using a DependencyProperty as the backing store for ChildPagerTemplate.  This enables animation, styling, binding, etc...
        public static readonly DependencyProperty ChildPagerTemplateProperty =
            DependencyProperty.RegisterAttached("ChildPagerTemplate", typeof(ControlTemplate), typeof(PagerTemplateChanger), new PropertyMetadata(null));

        #endregion

        #region ParentRow

        public static object GetParentRow(DependencyObject obj)
        {
            return (object)obj.GetValue(ParentRowProperty);
        }

        public static void SetParentRow(DependencyObject obj, object value)
        {
            obj.SetValue(ParentRowProperty, value);
        }

        // Using a DependencyProperty as the backing store for RowToCheck.  This enables animation, styling, binding, etc...
        public static readonly DependencyProperty ParentRowProperty =
            DependencyProperty.RegisterAttached("ParentRow", typeof(object), typeof(PagerTemplateChanger), new PropertyMetadata("nothing", OnParentRowChanged));

        private static void OnParentRowChanged(DependencyObject d, DependencyPropertyChangedEventArgs e)
        {
            PagerCellControl cellControl = d as PagerCellControl;
            if (cellControl == null || (e.NewValue != null && (e.NewValue is RowBase) == false))
                return;

            // if NewValue is null, there is no parent row so this is a parent pager control
            if (e.NewValue == null && GetParentPagerTemplate(cellControl) != null)
                cellControl.Template = GetParentPagerTemplate(cellControl);
            // if NewValue is not null then we're positive that this is a child pager
            else if (e.NewValue != null && GetChildPagerTemplate(cellControl) != null)
                cellControl.Template = GetChildPagerTemplate(cellControl);
        }

        #endregion
    }
}
